@@ -368,17 +368,16 @@ class GourmetApplication:
 
     def get_attribute_model (self, attribute):
         """Return a ListModel with a unique list of values for attribute.
-
-        This is stored here so that all the different comboboxes that
-        might need e.g. a list of categories can share 1 model and
-        save memory.
         """
-        if not hasattr(self,'%sModel'%attribute):
-            slist = self.create_attribute_list(attribute)
-            m = gtk.ListStore(str)
-            for i in slist: m.append([i])
-            setattr(self,'%sModel'%attribute,m)
-            self.attributeModels.append((attribute,getattr(self,'%sModel'%attribute)))
+        # This was stored here so that all the different comboboxes that
+        # might need e.g. a list of categories can share 1 model and
+        # save memory.
+        # if not hasattr(self,'%sModel'%attribute): 
+        slist = self.create_attribute_list(attribute)
+        m = gtk.ListStore(str)
+        for i in slist: m.append([i])
+        setattr(self,'%sModel'%attribute,m)
+        self.attributeModels.append((attribute,getattr(self,'%sModel'%attribute)))
         return getattr(self,'%sModel'%attribute)
 
     # About/Help
@@ -574,6 +573,7 @@ class RecTrash (RecIndex):
                                                                    {'size':(600,800)}),
                                                     show=False))
         self.window.connect('response',self.response_cb)
+        # So we can let delete key delete recipe when treeview is focused
 
     def response_cb (self, dialog, response):
         if response==self.RESPONSE_DELETE_PERMANENTLY:
@@ -867,6 +867,7 @@ ui = '''<ui>
     <menuitem action="ShopRec"/>
     <menuitem action="DeleteRec"/>    
     <separator/>
+    <menuitem action="EditRec"/>    
     <menuitem action="BatchEdit"/>
   </menu>
   <menu name="Go" action="Go">
@@ -1019,7 +1020,10 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
             if event.button==3:
                 self.rectree_popup(tv,event)
                 return True
+        # Set up popup menu in treeview
         self.rectree.connect('button-press-event',popcb)
+        # Set up delete key in recipe treeview
+        self.rectree.connect('key-press-event',self.rec_tree_keypress_cb)
         self.main.show()
 
     def rectree_popup (self, tv, event, *args):
@@ -1035,8 +1039,14 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
         self.onSelectedActionGroup.add_actions([
             ('OpenRec','recipe-box',_('Open recipe'),
              '<Control>O',_('Open selected recipe'),self.rec_tree_select_rec),
+            # We no longer bind "Delete" here -- instead, we'll do it
+            # at the TreeView level to prevent the delete key
+            # elsewhere (e.g. in search box) from muddling up users.
             ('DeleteRec',gtk.STOCK_DELETE,_('Delete recipe'),
-             'Delete',_('Delete selected recipes'),self.rec_tree_delete_rec_cb),
+             None,_('Delete selected recipes'),self.rec_tree_delete_rec_cb),
+            ('EditRec',gtk.STOCK_EDIT,_('Edit recipe'),
+             None,_('Open selected recipes in recipe editor view'),
+             self.rec_tree_edit_rec),
             ('ExportSelected',None,_('E_xport selected recipes'),
              None,_('Export selected recipes to file'),
              lambda *args: self.do_export(export_all=False)),
@@ -1156,7 +1166,20 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
         debug("rec_tree_select_rec (self, *args):",5)
         for rec in self.get_selected_recs_from_rec_tree():
             self.open_rec_card(rec)
-    
+
+    def rec_tree_edit_rec (self, *args):
+        for rec in self.get_selected_recs_from_rec_tree():
+            if self.rc.has_key(rec.id):
+                self.rc[rec.id].show_edit()
+            else:
+                def show ():
+                    w=reccard.RecCard(self, rec, manual_show=True)
+                    self.rc[rec.id]=w
+                    self.update_go_menu()
+                    w.show_edit()
+                    self.app.window.set_cursor(None)
+                self.app.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+                gobject.idle_add(show)
 
     # Deletion
     def show_deleted_recs (self, *args):
@@ -1166,14 +1189,19 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
         else:
             self.recTrash.show()
 
+    def rec_tree_keypress_cb (self, widget, event):
+        keyname = gtk.gdk.keyval_name(event.keyval)
+        if keyname == 'Delete' or keyname == 'BackSpace':
+            self.rec_tree_delete_rec_cb()
+            return True
 
-    def rec_tree_delete_rec_cb (self, *args):
+    def rec_tree_delete_rec_cb (self, *args,**kwargs):
         """Make a watch show up (this can be slow
         if lots of recs are selected!"""
         self.rec_tree_delete_recs(
             self.get_selected_recs_from_rec_tree()
             )
-
+        
     def delete_open_card_carefully (self, rec):
         """Delete any open card windows, confirming if the card is edited.
 
