@@ -5,6 +5,7 @@
 import shutil
 import types
 import os.path
+from gettext import gettext as _
 from gourmet.gdebug import debug, TimeAction, debug_decorator
 import re, pickle, string, os.path, string, time
 from gettext import gettext as _
@@ -20,6 +21,10 @@ from gourmet.plugin import DatabasePlugin
 
 import sqlalchemy, sqlalchemy.orm
 from sqlalchemy import Integer, Binary, String, Float, Boolean, Numeric, Table, Column, ForeignKey, Text
+try: 
+    from sqlalchemy import LargeBinary
+except:
+    from sqlalchemy import Binary as LargeBinary
 from sqlalchemy.sql import and_, or_, case 
 from sqlalchemy import func
 
@@ -35,7 +40,7 @@ def map_type_to_sqlalchemy (typ):
     if typ=='text': return Text()
     if typ=='bool': return Boolean()
     if typ=='float': return Float()
-    if typ=='binary': return Binary()
+    if typ=='binary': return LargeBinary()
 
 def fix_colnames (dict, *tables):
     """Map column names to sqlalchemy columns.
@@ -215,7 +220,11 @@ class RecData (Pluggable):
                 self.info_table,
                 {'last_access':time.time()}
                 )
-        self.db.commit()
+        try:
+            self.db.commit()
+        except IndexError:
+            print 'Ignoring sqlalchemy problem'
+            import traceback; traceback.print_exc()
 
     def _setup_object_for_table (self, table, klass):
         self.__table_to_object__[table] = klass
@@ -224,7 +233,7 @@ class RecData (Pluggable):
             sqlalchemy.orm.mapper(klass,table)
         else:
             # if there's no primary key...
-            raise "All tables need a primary key -- specify 'rowid'/Integer/Primary Key in table spec for %s"%table
+            raise Exception("All tables need a primary key -- specify 'rowid'/Integer/Primary Key in table spec for %s" % table)
 
     @pluggable_method
     def setup_tables (self):
@@ -291,8 +300,8 @@ class RecData (Pluggable):
                                   Column('servings',Float(),**{}), 
                                   Column('yields',Float(),**{}),                                  
                                   Column('yield_unit',String(length=32),**{}),
-                                  Column('image',Binary(),**{}),
-                                  Column('thumb',Binary(),**{}),
+                                  Column('image',LargeBinary(),**{}),
+                                  Column('thumb',LargeBinary(),**{}),
                                   Column('deleted',Boolean(),**{}),
                                   # A hash for uniquely identifying a recipe (based on title etc)
                                   Column('recipe_hash',String(length=32),**{}),
@@ -491,13 +500,21 @@ class RecData (Pluggable):
                 print 'Upgrade from < 0.14',sv_text
                 self.alter_table('categories',self.setup_category_table,
                                  {'id':'recipe_id'},['category'])
-                print 'RECREATE INGREDIENTS TABLE (This could take a while...)'
-                self.alter_table('ingredients',self.setup_ingredient_table,
-                                 {'id':'recipe_id'},
-                                 ['refid', 'unit', 'amount', 'rangeamount',
-                                  'item', 'ingkey', 'optional', 'shopoptional',
-                                  'inggroup', 'position', 'deleted'])
-                print 'RECREATE KEYLOOKUP TABLE'
+                # Testing whether somehow recipe_id already exists
+                # (apparently the version info here may be off? Not
+                # sure -- this is coming from an odd bug report by a
+                # user reported at...
+                # https://sourceforge.net/projects/grecipe-manager/forums/forum/371768/topic/3630545?message=8205906
+                try:
+                    self.db.connect().execute('select recipe_id from ingredients')
+                except sqlite3.OperationalError:
+                    self.alter_table('ingredients',self.setup_ingredient_table,
+                                     {'id':'recipe_id'},
+                                     ['refid', 'unit', 'amount', 'rangeamount',
+                                      'item', 'ingkey', 'optional', 'shopoptional',
+                                      'inggroup', 'position', 'deleted'])
+                else:
+                    print 'Odd -- recipe_id seems to already exist'
                 self.alter_table('keylookup',self.setup_keylookup_table,
                                  {},['word','item','ingkey','count'])
             # Add recipe_hash, ingredient_hash and link fields
@@ -677,7 +694,7 @@ class RecData (Pluggable):
     def fetch_join (self, table1, table2, col1, col2,
                     column_names=None, sort_by=[], **criteria):
         if column_names:
-            raise 'column_names KWARG NO LONGER SUPPORTED BY fetch_join!'
+            raise Exception("column_names KWARG NO LONGER SUPPORTED BY fetch_join!")
         return  table1.join(table2,getattr(table1.c,col1)==getattr(table2.c,col2)).select(
             *make_simple_select_arg(criteria,table1,table2)
             ).execute().fetchall()
@@ -749,16 +766,21 @@ class RecData (Pluggable):
             else:
                 subtable = None
                 col = getattr(self.recipe_table.c,crit['column'])
+            # Make sure we're using unicode!
+            if (type(crit.get('search',u'')) != unicode
+                and type(crit.get('search',u'')) in types.StringTypes):
+                crit['search'] = unicode(crit['search'])
             if crit.get('operator','LIKE')=='LIKE':
                 retval = (col.like(crit['search']))
             elif crit['operator']=='REGEXP':
                 retval = (col.op('REGEXP')(crit['search']))
             else:
                 retval = (col==crit['search'])
-            if subtable:
+            if subtable is not None:
                 retval = self.recipe_table.c.id.in_(
                     sqlalchemy.select([subtable.c.recipe_id],retval)
                     )
+            
             return retval
 
     def search_recipes (self, searches, sort_by=[]):
@@ -773,6 +795,7 @@ class RecData (Pluggable):
             d = (sort_by[i][1]==1 and -1 or 1)
             sort_by[i] = ('rating',d)
         criteria = self.get_criteria((searches,'and'))
+        debug('backends.db.search_recipes - search criteria are %s'%searches,2)
         if 'category' in [s[0] for s in sort_by]:
             return sqlalchemy.select([c for c in self.recipe_table.c],# + [self.categories_table.c.category],
                                      criteria,distinct=True,
@@ -785,16 +808,9 @@ class RecData (Pluggable):
                                      order_by=make_order_by(sort_by,self.recipe_table,),
                                      ).execute().fetchall()
 
-    def filter (self, table, func):
-        """Return a table representing filtered with func.
-
-        func is called with each row of the table.
-        """
-        raise NotImplementedError
-
     def get_unique_values (self, colname,table=None,**criteria):
         """Get list of unique values for column in table."""
-        if not table: table=self.recipe_table
+        if table is None: table=self.recipe_table
         if criteria: table = table.select(*make_simple_select_arg(criteria,table))
         if colname=='category' and table==self.recipe_table:
             print 'WARNING: you are using a hack to access category values.'
@@ -1761,16 +1777,24 @@ class RecipeManager (RecData):
         else:
             return None
 
-    def ingredient_parser (self, s, conv=None, get_key=True):
+    def parse_ingredient (self, s, conv=None, get_key=True):
         """Handed a string, we hand back a dictionary representing a parsed ingredient (sans recipe ID)"""
+        if conv:
+            print 'parse_ingredient: conv argument is now ignored'
         debug('ingredient_parser handed: %s'%s,0)
-        s = unicode(s) # convert to unicode so our ING MATCHER works properly
-        s=s.strip("\n\t #*+-")
+        # Strip whitespace and bullets...
+        d={}
+        s = s.decode('utf8').strip(
+            u'\u2022\u2023\u2043\u204C\u204D\u2219\u25C9\u25D8\u25E6\u2619\u2765\u2767\u29BE\u29BF\n\t #*+-')
+        s = unicode(s)
+        option_m = re.match('\s*optional:?\s*',s,re.IGNORECASE)
+        if option_m:
+            s = s[option_m.end():]
+            d['optional']=True
         debug('ingredient_parser handed: "%s"'%s,1)
         m=convert.ING_MATCHER.match(s)
         if m:
             debug('ingredient parser successfully parsed %s'%s,1)
-            d={}
             a,u,i=(m.group(convert.ING_MATCHER_AMT_GROUP),
                    m.group(convert.ING_MATCHER_UNIT_GROUP),
                    m.group(convert.ING_MATCHER_ITEM_GROUP))
@@ -1782,6 +1806,7 @@ class RecipeManager (RecData):
                 else:
                     d['amount']=convert.frac_to_float(a.strip())
             if u:
+                conv = convert.get_converter()
                 if conv and conv.unit_dict.has_key(u.strip()):
                     # Don't convert units to our units!
                     d['unit']=u.strip()
@@ -1804,7 +1829,10 @@ class RecipeManager (RecData):
             return d
         else:
             debug("Unable to parse %s"%s,0)
-            return None
+            d['item'] = s
+            return d
+        
+    ingredient_parser = parse_ingredient
 
     def ing_search (self, ing, keyed=None, recipe_table=None, use_regexp=True, exact=False):
         """Search for an ingredient."""
