@@ -124,7 +124,7 @@ class BeautifulSoupScraper:
         elif len(rule)==4:
             store_as,tagpath,retmethod,post_processing=rule
         else:
-            raise "Rule %s is invalid (it should be 3 or 4 items long)."%rule
+            raise Exception("Rule %s is invalid (it should be 3 or 4 items long)." % rule)
         tag = self.get_tag_according_to_path(tagpath)
         self.store_tag(store_as,tag,retmethod,post_processing)
 
@@ -481,13 +481,14 @@ class WebPageImporter (importer.Importer):
                 the new generic web importer!
                 """
         if do_generic:
-            if not self.interactive: raise "Unable to find importer for %s"%self.url
+            if not self.interactive:
+                raise Exception("Unable to find importer for %s" % self.url)
             # Interactive we go...
             self.prog(-1,_("Don't recognize this webpage. Using generic importer..."))
             gs = GenericScraper()
             text,images = gs.scrape_url(self.url, progress=self.prog)
             if not text and not images:
-                raise "Unable to obtain text or images from url %s"%self.url
+                raise Exception("Unable to obtain text or images from url %s" % self.url)
             import interactive_importer
             ii = interactive_importer.InteractiveImporter(self.rd)
             ii.set_text(text)
@@ -525,7 +526,7 @@ class WebPageImporter (importer.Importer):
                     # we take a special keyword, "text", which gets
                     # parsed
                     if ingdic.has_key('text'):
-                        d = self.rd.ingredient_parser(ingdic['text'],conv=self.conv)
+                        d = self.rd.parse_ingredient(ingdic['text'],conv=self.conv)
                         if d:
                             for dk,dv in d.items():
                                 if not ingdic.has_key(dk) or not ingdic[dk]:
@@ -546,7 +547,7 @@ class WebPageImporter (importer.Importer):
             if k == 'ingredient_block':
                 for l in v.split('\n'):
                     if self.prog: self.prog(-1,_('Processing ingredients.'))
-                    dic=self.rd.ingredient_parser(l,conv=self.conv)
+                    dic=self.rd.parse_ingredient(l,conv=self.conv)
                     if dic:
                         self.start_ing(**dic)
                         self.commit_ing()
