@@ -35,15 +35,20 @@ class KeyManager:
         self.ignored = defaults.IGNORE
         self.ignored.extend(self.cooking_verbs)
         self.ignored_regexp = re.compile("[,; ]?(" + '|'.join(self.ignored) + ")[,; ]?")
-        #if not(self.rm.keylookup_table): # wrong
         if self.rm.fetch_len(self.rm.keylookup_table) == 0:
             self.initialize_from_defaults()
         self.initialize_categories()
         
     def initialize_from_defaults (self):
+        dics = []
         for key,items in defaults.keydic.items():
             for i in items:
-                self.rm.add_ing_to_keydic(i,key)
+                dics.append(
+                    {'ingkey':unicode(key),
+                     'item':unicode(i),
+                     'count':1}
+                    )
+        self.rm.keylookup_table.insert().execute(dics)
 
     def make_regexp_for_strings (self, ignored):
         ret = "("
@@ -189,7 +194,10 @@ class KeyManager:
                 # resulted in this key, matches is the number of keys
                 # that match this word in all, and words is the number
                 # of words we're dealing with.
-                retvals[ik]+=(float(m.count)/total_count)*(float(1)/nwords)
+                words_in_key = len(ik.split())
+                if words_in_key > nwords: wordcount = words_in_key
+                else: wordcount = nwords
+                retvals[ik]+=(float(m.count)/total_count)*(float(1)/(wordcount))
                 # Add some probability if our word shows up in the key
                 if ik.find(w)>=0: retvals[ik]+=0.1
         retv = retvals.items()
@@ -225,7 +233,6 @@ class KeyManager:
         timer.end()
         return ingr
 
-
     def sing_equal(self, str1, str2):
         debug("Start sing_equal(self,%s,%s)"%(str1,str2),10)
         sing_str1 = self.remove_final_s(str1)
