@@ -25,11 +25,12 @@
 # Application to muck about with.
 #
 # RecDisplayPlugin - given an instance of the recipe display card.
-# RecEditPlugin - given an instance of the recipe editor.
+# RecEditorPlugin - given an instance of the recipe editor.
 # DatabasePlugin - given an instance of the base database class.
 
-import Undo, gtk, types
+import Undo, gtk, gobject, types
 import plugin_loader
+from gtk_extras import fix_action_group_importance
 
 class Plugin:
     pass
@@ -148,9 +149,15 @@ class BaseExporterPlugin (Plugin):
         for hook in self.hooks_to_add:
             pluggable.add_hook(*hook)
 
+    def remove (self):
+        for hook in self.hooks_to_add:
+            self.pluggable.remove_hook(*hook)
+        self.pluggable.plugins.remove(self)
+
     def add_field (self, field_name, field_fetcher,
                    type,
-                   position=plugin_loader.POST):
+                   position=plugin_loader.POST,
+                   write_empty_field=False):
         '''Add a text field to our export.
 
         field_name is the name of the field.
@@ -163,6 +170,10 @@ class BaseExporterPlugin (Plugin):
 
         position is either PRE or POST -- whether we come before or
         after other text fields.
+
+        if write_empty_field is True, we will write the field
+        regardless of the value. Otherwise, non-True (i.e. blank)
+        values will not print.
         '''
         if type==self.TEXT:
             def do_write (*args):
@@ -175,7 +186,7 @@ class BaseExporterPlugin (Plugin):
                 if klass.do_markup:
                     val = klass.handle_markup(val)
                 if not val: val = ''
-                if klass.ALLOW_PLUGINS_TO_WRITE_NEW_FIELDS:
+                if klass.ALLOW_PLUGINS_TO_WRITE_NEW_FIELDS and (val or write_empty_field):
                     klass.write_text(field_name,val)
             self.hooks_to_add.append((position,'_write_text_',do_write))
         else:
@@ -188,7 +199,7 @@ class BaseExporterPlugin (Plugin):
                 val = field_fetcher(klass.r)
                 if klass.do_markup:
                     val = klass.handle_markup(val)
-                if klass.ALLOW_PLUGINS_TO_WRITE_NEW_FIELDS:                
+                if klass.ALLOW_PLUGINS_TO_WRITE_NEW_FIELDS and (val or write_empty_field):                
                     klass.write_attr(field_name,val)
             self.hooks_to_add.append((position,'_write_attrs_',do_write))
 
@@ -212,7 +223,7 @@ class DatabasePlugin (StandardPlugin):
                 # updates.
 
     active = False
-    
+
     def activate (self, db):
         if self.active:
             print 'Strange -- activate called twice'
@@ -223,7 +234,6 @@ class DatabasePlugin (StandardPlugin):
         self.db = db
         if db._created:
             # For creation after DB is initialized...
-            print 'Table already created -- create tables now.'
             self.create_tables()
             
             self.db.metadata.create_all()
@@ -232,8 +242,8 @@ class DatabasePlugin (StandardPlugin):
             db.add_hook(plugin_loader.POST,'setup_tables',self.create_tables)
         self.active = True
         
-    def deactivate (self, db):
-        db.remove_hook(plugin_loader.POST,'setup_tables',self.create_tables)
+    def remove (self):
+        self.db.remove_hook(plugin_loader.POST,'setup_tables',self.create_tables)
         self.active = False
         
     def create_tables (self):
@@ -293,7 +303,6 @@ class UIPlugin (StandardPlugin, UIModule):
         self.add_to_uimanager(pluggable.ui_manager)
 
     def remove (self):
-        #print 'remove!',self
         for uimanager in self.merged:
             merge_id,action_ids = self.merged[uimanager]
             for ag in action_ids: uimanager.remove_action_group(ag)
@@ -303,6 +312,7 @@ class UIPlugin (StandardPlugin, UIModule):
         merge_id = uimanager.add_ui_from_string(self.ui)
         action_ids = []
         for ag in self.action_groups:
+            fix_action_group_importance(ag)
             uimanager.insert_action_group(ag,0)
             action_ids.append(ag)
         self.merged[uimanager] = merge_id,action_ids    
@@ -337,6 +347,23 @@ class RecDisplayPlugin (StandardPlugin):
         for pluggable in self.pluggables:
             pluggable.remove_plugin_from_left_notebook(self.moduleKlass)
 
+class RecEditorPlugin (StandardPlugin):
+
+    '''A plugin for our recipe editor.
+
+    moduleKlass is a module to add (provides a new tabby interface on
+    the recEditor) and position is the position of that new module.
+
+    '''
+
+    moduleKlass = None
+    position = None
+
+    def activate (self, pluggable):
+        if not hasattr(self,'pluggables'): self.pluggables = []
+        pluggable.add_plugin(self.moduleKlass,self.position)
+        self.pluggables.append(pluggable)
+
 class MainPlugin (StandardPlugin):
 
     added_tabs = []
@@ -370,7 +397,6 @@ class PluginPlugin (StandardPlugin):
         # list accordingly.
         if self.target_pluggable in pluggable.targets:
             # do_activate is where we do our real activation
-            pluggable.plugins.append(self)
             self.do_activate(pluggable)
         else:
             # nevermind... we're not for this pluggable
@@ -385,9 +411,15 @@ class RecDisplayModule (UIModule):
         self.rd = recDisplay; self.rg = self.rd.rg
         UIModule.__init__(self)
 
-class RecEditorModule (UIModule):
+class RecEditorModule (UIModule, gobject.GObject, object):
+
+    __gsignals__ = {
+        'saved':(gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,[]),
+        'toggle-edited':(gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,[gobject.TYPE_BOOLEAN]),
+        }
     
     def __init__ (self, recEditor):
+        gobject.GObject.__init__(self)
         self.action_groups = [] # a list of ActionGroups to be inserted into the uimanager.        
         self.re = recEditor
         self.rg = self.re.rg
@@ -396,6 +428,16 @@ class RecEditorModule (UIModule):
         self.setup_undo()
         self.setup_main_interface()
 
+    __edited = False
+    def get_edited (self):
+        return self.__edited
+    def set_edited (self, val):
+        self.__edited = val
+        self.emit('toggle-edited',val)
+        return val
+
+    edited = property(get_edited,set_edited)
+
     def setup_undo (self):
         self.undoActionGroup = gtk.ActionGroup(self.name+'UndoActions')
         self.undoActionGroup.add_actions([
@@ -422,6 +464,7 @@ class RecEditorModule (UIModule):
         Do any modifications to other tables.
         Return possibly modified recipe dictionary
         """
+        self.emit('saved')
         return recdict
 
     def undo_action_callback (self, undo_history, action, typ):
@@ -481,6 +524,72 @@ class RecEditorModule (UIModule):
                 else:
                     self.re.widgets_changed_since_save[widget]=[action]
         if self.re.widgets_changed_since_save:
-            self.re.set_edited(True)
+            self.edited = True
         else:
-            self.re.set_edited(False)
+            self.edited = False
+
+class IngredientControllerPlugin (StandardPlugin):
+    '''Plugins for mucking about with how ingredient information is
+    edited and stored.
+    '''
+    pass
+
+class ShoppingListPlugin (UIPlugin):
+
+    ui = ''
+
+    def __init__ (self):
+        UIPlugin.__init__(self)
+
+
+class PrinterPlugin (StandardPlugin):
+
+    # SimpleWriter class
+    SimpleWriter = None
+    # how good this printer is (0 = use it if nothing else is there,
+    # and up from there)
+    simpleWriterPriority = -2
+    RecWriter = None # RecWriter class
+    recWriterPriority = -2
+    pass
+    
+    def activate (self, pluggable):
+        pluggable.register_plugin(self)
+
+    def deactivate (self, pluggable):
+        pluggable.unregister_plugin(self)
+
+class PrefsPlugin (StandardPlugin):
+
+    '''Add a tab to the preferences notebook.
+
+    Pretty much all of the handling is offloaded to the widget you add.
+
+    If you want to handle applying using the prefsGui system, you can do it with...
+
+    self.prefsGui.apply_prefs_dic['prefname']=function
+
+    where function takes then name and value of the preference as its arguments.
+    '''
+
+    label = None
+    widget = None
+
+    def activate (self, pluggable):
+        self.prefsGui = pluggable
+        self.notebook = pluggable.notebook
+        if self.label and self.widget:
+            self.page_no = self.notebook.append_page(self.widget,tab_label=gtk.Label(self.label))
+            self.widget.show()
+
+    def deactivate (self, pluggable):
+        self.notebook = None
+        self.prefsGui = None
+
+    def remove (self):
+        if self.notebook:
+            self.notebook.remove_page(self.page_no)
+            
+    def set_pref (self, name, value):
+        self.prefsGui.set_pref(name,value)
+        
