@@ -34,4 +34,4 @@ class PdfExporterPlugin (ExporterPlugin):
         return pdf_exporter.get_pdf_prefs()
 
     def get_default_prefs (self):
-        return pdf_exporter.PDF_PREF_DEFAULT
+        return pdf_exporter.DEFAULT_PDF_ARGS
