@@ -17,7 +17,6 @@ class NutritionDisplayModule (RecDisplayModule):
     _custom_handlers_setup = False
 
     def __init__ (self, recipe_display):
-        print 'Initialize NutritionDisplayModule for',recipe_display
         self.recipe_display = recipe_display
         self.nutritional_highlighting = True
         self.prefs = self.recipe_display.rg.prefs
@@ -28,8 +27,11 @@ class NutritionDisplayModule (RecDisplayModule):
     def update_from_database (self):
         self.nutinfo = self.recipe_display.rg.rd.nd.get_nutinfo_for_inglist(self.recipe_display.rg.rd.get_ings(self.recipe_display.current_rec),
                                                                             self.recipe_display.rg.rd)
-        print 'Set servings',self.recipe_display.current_rec.servings,type(self.recipe_display.current_rec.servings)
-        self.nutritionLabel.set_servings(self.recipe_display.current_rec.servings)
+        #print 'Set servings',self.recipe_display.current_rec.servings,type(self.recipe_display.current_rec.servings)
+        self.nutritionLabel.set_yields(
+            self.recipe_display.current_rec.yields,
+            self.recipe_display.current_rec.yield_unit
+                                       )
         self.nutritionLabel.set_nutinfo(self.nutinfo)
         self.nutritionLabel.rec = self.recipe_display.current_rec
         
@@ -65,20 +67,23 @@ class NutritionDisplayModule (RecDisplayModule):
     def enter_page (self):
         self.nutritional_highlighting = True
         if not self.nutritionLabel.active_name:
-            self.nutritionLabel.toggles[self.prefs.get('nutrition_to_highlight','kcal')].activate()
+            if self.prefs.get('nutrition_to_highlight','kcal') in self.nutritionLabel.toggles:
+                self.nutritionLabel.toggles[
+                    self.prefs.get(
+                        'nutrition_to_highlight','kcal')
+                    ].activate()
         # Save what servings were and set them to "1" so that the
         # ingredient amounts display how much goes into each servings
-        # (assuming there are servings)
+        # (assuming there is a yield value)
         self.mult_orig = self.recipe_display.mult
-        if self.recipe_display.current_rec.servings:
-            self.recipe_display.mult = 1.0/self.recipe_display.current_rec.servings
+        if self.recipe_display.current_rec.yields:
+            self.recipe_display.mult = 1.0/self.recipe_display.current_rec.yields
         self.recipe_display.ingredientDisplay.display_ingredients()
 
     def setup_ingredient_display_hooks (self):
         self.ingredientDisplay = self.recipe_display.ingredientDisplay
         self.ingredientDisplay.markup_ingredient_hooks.append(self.nutritional_markup_hook)
 
-    # SHOULD BECOME PART OF NUTRITIONAL PLUGIN
     def nutritional_markup_hook (self, istr, ing, ing_index, group_index):
         if self.nutritional_highlighting and self.nutritionLabel.active_name:
             props = self.nutritionLabel.active_properties
@@ -101,7 +106,7 @@ class NutritionDisplayModule (RecDisplayModule):
                 tot_amt = sum([getattr(self.nutinfo,p) or 0 for p in props])
             if nut_amt:
                 perc = float(nut_amt)/tot_amt
-                if self.recipe_display.serves_orig: nut_amt = nut_amt/self.recipe_display.serves_orig
+                if self.recipe_display.yields_orig: nut_amt = nut_amt/self.recipe_display.yields_orig
                 label = self.nutritionLabel.active_unit
                 if not self.nutritionLabel.active_unit:
                     label = self.nutritionLabel.active_label.lower()
@@ -122,10 +127,8 @@ class NutritionDisplayModule (RecDisplayModule):
                     istr = '<span weight="%i">'%weight + istr + '</span>'
             if isinstance(nutinfo_for_ing,
                           NutritionVapor):
-                print 'Vapor!',nutinfo_for_ing
                 istr = '<span foreground="red">'+istr+'</span>'
         return istr
-
         
 
 class NutritionDisplayPlugin (RecDisplayPlugin):
