@@ -960,7 +960,7 @@ class ShopGui (plugin_loader.Pluggable, IngredientAndPantryList):
 
     def item_added (self, *args):
 	txt = self.add_entry.get_text()
-	dct = self.rd.ingredient_parser(txt)
+	dct = self.rd.parse_ingredient(txt)
 	if not dct: dct = {'amount':None,'unit':None,'item':txt}
 	self.extras.append([dct.get('amount'),dct.get('unit'),dct.get('item')])
         # Make sure it doesn't end up in the pantry...        
@@ -1097,7 +1097,7 @@ def getOptionalIngDic (ivw, mult, prefs, rg=None):
         if retval:
             return retval
         else:
-            raise "Option Dialog cancelled!"
+            raise Exception("Option Dialog cancelled!")
 
 if __name__ == '__main__':
     class TestIngredientAndPantryList (IngredientAndPantryList):
